// Copyright 1998-2014 Epic Games, Inc. All Rights Reserved.

#pragma once

#include "SlateWidgetStyleContainerBase.h"
#include "ResourceBarStyle.generated.h"

/**
* Represents the appearance of an SShooterScoreboardWidget
*/
USTRUCT()
struct GUILIBRARY_API FResourceBarWidgetStyle : public FSlateWidgetStyle
{
	GENERATED_USTRUCT_BODY()

	FResourceBarWidgetStyle();
	virtual ~FResourceBarWidgetStyle();

	// FSlateWidgetStyle
	virtual void GetResources(TArray<const FSlateBrush*>& OutBrushes) const override;
	static const FName TypeName;
	virtual const FName GetTypeName() const override{ return TypeName; };
	static const FResourceBarWidgetStyle& GetDefault();

	/** Resource bar size. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FVector2D DesiredSize;

	/** Background brush represents 'empty' state of this resource bar. Most likely it will be transparent or semi-transparent. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush BackgroundBrush;
	FResourceBarWidgetStyle& SetBackgroundBrush(const FSlateBrush& InItemBorderBrush) { BackgroundBrush = InItemBorderBrush; return *this; }

	/** Foreground brush represents 'full' state of this resource bar. Most likely it will be opaque. This Brush is drawn ON TOP of Background brush!. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush ForegroundBrush;
	FResourceBarWidgetStyle& SetForegroundBrush(const FSlateBrush& InItemBorderBrush) { ForegroundBrush = InItemBorderBrush; return *this; }

	/** Border is just a decorator and is drawn ON TOP of ForegroundBrush!. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush ItemBorderBrush;
	FResourceBarWidgetStyle& SetItemBorderBrush(const FSlateBrush& InItemBorderBrush) { ItemBorderBrush = InItemBorderBrush; return *this; }

	/** DecoratorBrush is  drawn on TOP of everything. Unlike border brush it wont be clipped to widget size! This brush will be clipped by parent window only!. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush DecoratorBrush;
	FResourceBarWidgetStyle& SetDecoratorBrush(const FSlateBrush& InDecoratorBrush) { DecoratorBrush = InDecoratorBrush; return *this; }

	/** Here you can control offset of Decorator brush from Widget location. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FVector2D DecoratorOffset;

	/** Should we draw label? If so, the format will be: "CurrentValue / MaxValue" */
	UPROPERTY(EditAnywhere, Category = Appearance)
	bool DrawLabel;

	/** Should we draw label on hover? */
	UPROPERTY(EditAnywhere, Category = Appearance)
	bool DrawLabelOnHover;

	/** Label text style. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FTextBlockStyle LabelText;
};


/**
*/
UCLASS(hidecategories = Object, MinimalAPI)
class UResourceBarStyle : public USlateWidgetStyleContainerBase
{
	GENERATED_UCLASS_BODY()

public:
	/** The actual data describing the scoreboard's appearance. */
	UPROPERTY(Category = Appearance, EditAnywhere, meta = (ShowOnlyInnerProperties))
		FResourceBarWidgetStyle ResourceBarStyle;

	virtual const struct FSlateWidgetStyle* const GetStyle() const override
	{
		return static_cast< const struct FSlateWidgetStyle* >(&ResourceBarStyle);
	}
};
